@@ -10,90 +10,90 @@ use Acme::Pythonic::Functions;
 
 use Acme::Pythonic; # Enables Python-like indentation-conventions.
 
-pront "Strings:"
+pyprint "Strings:"
 
 $a = "Hello"
 
 if endswith($a, "ello"):
-    pront '$a ends with "ello".'
+    pyprint '$a ends with "ello".'
 
 if isin($a, "ll", "s"):
-    pront '"ll" is in $a.'
+    pyprint '"ll" is in $a.'
 
 $a = "2345"
 
 if isdigit($a):
-    pront '$a is a digit.'
+    pyprint '$a is a digit.'
 
 $a = "    Line    "
 
-pront lstrip($a)
+pyprint lstrip($a)
 $a = replace($a, "Line", "Another line")
-pront $a
-pront rstrip($a)
+pyprint $a
+pyprint rstrip($a)
 
 $a = "Hello"
 
 if startswith($a, "He"):
-    pront '$a starts with "He".'
+    pyprint '$a starts with "He".'
 
-pront len($a, "s")
+pyprint len($a, "s")
 
-pront
-pront "Lists:"
+pyprint
+pyprint "Lists:"
 
 @a = ("a", "b", "c")
 $b = "d"
 
 @a = append(@a, $b)
 
-pront @a
+pyprint @a
 
 @a = ("a", "b", "c")
 @b = (1, 2, 3)
 
 @a = extend(@a, @b)
 
-pront @a
+pyprint @a
 
 if isin(@a, "c", "l"):
-    pront '"c" is in @a.'
+    pyprint '"c" is in @a.'
 
 @a = insert(@a, 1, "a2")
 
-pront @a
+pyprint @a
 
-pront len(@a, "l")
+pyprint len(@a, "l")
 
 @a = remove(@a, "a2")
 
-pront @a
+pyprint @a
 
-pront
-pront "Hashes:"
+pyprint
+pyprint "Hashes:"
 
 %a = ("a" => 1, "b" => 2, "c" => 3)
 
 if has_key(%a, "c"):
-    pront '%a has a key "c".'
+    pyprint '%a has a key "c".'
 
 if isin(%a, "c", "h"):
-    pront '%a has a key "c".'
+    pyprint '%a has a key "c".'
 
-pront
-pront "File-related:"
+pyprint
+pyprint "File-related:"
 
 if isdir("/home/user"):
-    pront "Is directory."
+    pyprint "Is directory."
 
 if isfile("/home/user/myfile"):
-    pront "Is file."
+    pyprint "Is file."
 
 @a = ("a\n", "b\n", "c\n")
 
 if isfile("test12345.txt"):
 
-    pront 'File "test12345.txt" already exists. Nothing done.'
+    pyprint 'File "test12345.txt" already exists. Nothing done.'
 
 else:
 
@@ -103,11 +103,11 @@ else:
     for $i @c:
         $i = rstrip($i)
         print $i . " " 
-    pront
+    pyprint
 
-pront
-pront oslistdir(".")
+pyprint
+pyprint oslistdir(".")
 
-pront
-pront "System-related:"
-pront osname()
+pyprint
+pyprint "System-related:"
+pyprint osname()
