@@ -29,7 +29,7 @@ use Exporter;
 our ($VERSION, @ISA, @EXPORT);
 @ISA         = qw(Exporter);
 
-$VERSION     = 0.39;
+$VERSION     = 0.40;
 
 @EXPORT      = qw(append endswith extend has_key insert isdigit isin isdir isfile len listdir lstrip lstrip2 oslistdir osname pyprint readfile remove replace rstrip rstrip2 startswith strip writefile);
 
@@ -61,37 +61,38 @@ sub checkArgs {
 
 sub pyprint {
     if ($#_ == -1) {
+        print "\n";
         return;
     }
     if ($#_ == 0) {
         print ("$_[0]\n");
         return;
     }
-    # Print the array similar to a (2D-)Python-list:
+    # Print the array similar to a Python-list:
     my @a = @_;
     my $s;
     my $i;
-    $s = "[";
+    print "[";
     for $i (0 .. $#a) {
-        if ($a[$i] =~ /[^0-9-]/) {
-            $s .= "\"$a[$i]\"";
+        # Put quotation-marks around strings, but not around references:
+        if ($a[$i] =~ /[^0-9-]/ && ref($a[$i]) eq "") {
+            print "\"$a[$i]\"";
         } else {
-            $s .= $a[$i];
+            print $a[$i];
         }
         if ($i != $#a) {
-            $s .= ", ";
+            print ", ";
         } else {
-            $s .= "]\n";
+            print "]\n";
         }
     }
-    print $s;
 }
 
 # String-Functions
 
 sub endswith {
 
-    &checkArgs(2, @_);
+    checkArgs(2, @_);
 
     if ($_[0] =~ /\Q$_[1]\E$/) {
         return 1;
@@ -104,7 +105,7 @@ sub endswith {
 
 sub lstrip {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     my $a = $_[0];
 
@@ -116,7 +117,7 @@ sub lstrip {
 
 sub isdigit {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     if($_[0] =~ /\D/) {
         return 0;
@@ -129,7 +130,7 @@ sub isdigit {
 
 sub lstrip2 {
 
-    &checkArgs(2, @_);
+    checkArgs(2, @_);
 
     my ($a, $b) = @_;
 
@@ -181,7 +182,7 @@ sub replace {
 
 sub rstrip {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     my $a = $_[0];
 
@@ -193,7 +194,7 @@ sub rstrip {
 
 sub rstrip2 {
 
-    &checkArgs(2, @_);
+    checkArgs(2, @_);
 
     my ($a, $b) = @_;
 
@@ -211,7 +212,7 @@ sub rstrip2 {
 
 sub startswith {
 
-    &checkArgs(2, @_);
+    checkArgs(2, @_);
 
     if ($_[0] =~ /^\Q$_[1]\E/) {
         return 1;
@@ -224,7 +225,7 @@ sub startswith {
 
 sub strip {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     my $a = $_[0];
 
@@ -432,7 +433,7 @@ sub len {
 
 sub isdir {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     if(-d $_[0]) {
         return 1;
@@ -444,7 +445,7 @@ sub isdir {
 
 sub isfile {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     if(-f $_[0]) {
         return 1;
@@ -456,7 +457,7 @@ sub isfile {
 
 sub readfile {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     my $file = shift;
 
@@ -485,7 +486,7 @@ sub writefile {
 
 sub listdir {
 
-    &checkArgs(1, @_);
+    checkArgs(1, @_);
 
     my $dir = shift;
     if (! -d $dir) {
@@ -511,7 +512,7 @@ sub oslistdir {
 
 sub osname {
 
-    &checkArgs(0);
+    checkArgs(0);
 
     return $^O;
 }
